==> haskell-tls-1.5.4-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tls
version:              1.5.4
visibility:           public
id:                   tls-1.5.4-G5dyG2FHNNCAlxHHj5pIVt
key:                  tls-1.5.4-G5dyG2FHNNCAlxHHj5pIVt
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-tls
synopsis:             TLS/SSL protocol native implementation (Server and Client)
description:
    Native Haskell TLS and SSL protocol implementation for server and client.

    This provides a high-level implementation of a sensitive security protocol,
    eliminating a common set of security issues through the use of the advanced
    type system, high level constructions and common Haskell features.

    Currently implement the SSL3.0, TLS1.0, TLS1.1, TLS1.2 and TLS 1.3 protocol,
    and support RSA and Ephemeral (Elliptic curve and regular) Diffie Hellman key exchanges,
    and many extensions.

    Some debug tools linked with tls, are available through the
    <http://hackage.haskell.org/package/tls-debug/>.

category:             Network
abi:                  75964162873e83adbf0bf5ee09d20e5f
exposed:              True
exposed-modules:
    Network.TLS Network.TLS.Cipher Network.TLS.Compression
    Network.TLS.Extra Network.TLS.Extra.Cipher Network.TLS.Extra.FFDHE
    Network.TLS.Internal

hidden-modules:
    Network.TLS.Cap Network.TLS.Struct Network.TLS.Struct13
    Network.TLS.Core Network.TLS.Context Network.TLS.Context.Internal
    Network.TLS.Credentials Network.TLS.Backend Network.TLS.Crypto
    Network.TLS.Crypto.DH Network.TLS.Crypto.IES
    Network.TLS.Crypto.Types Network.TLS.ErrT Network.TLS.Extension
    Network.TLS.Handshake Network.TLS.Handshake.Common
    Network.TLS.Handshake.Common13 Network.TLS.Handshake.Certificate
    Network.TLS.Handshake.Key Network.TLS.Handshake.Client
    Network.TLS.Handshake.Server Network.TLS.Handshake.Process
    Network.TLS.Handshake.Random Network.TLS.Handshake.Signature
    Network.TLS.Handshake.State Network.TLS.Handshake.State13
    Network.TLS.Hooks Network.TLS.IO Network.TLS.Imports
    Network.TLS.KeySchedule Network.TLS.MAC Network.TLS.Measurement
    Network.TLS.Packet Network.TLS.Packet13 Network.TLS.Parameters
    Network.TLS.PostHandshake Network.TLS.Record
    Network.TLS.Record.Types Network.TLS.Record.Engage
    Network.TLS.Record.Disengage Network.TLS.Record.State
    Network.TLS.RNG Network.TLS.State Network.TLS.Session
    Network.TLS.Sending Network.TLS.Sending13 Network.TLS.Receiving
    Network.TLS.Receiving13 Network.TLS.Util Network.TLS.Util.ASN1
    Network.TLS.Util.Serialization Network.TLS.Types Network.TLS.Wire
    Network.TLS.X509

import-dirs:          /usr/lib/ghc-8.10.2/site-local/tls-1.5.4
library-dirs:         /usr/lib/ghc-8.10.2/site-local/tls-1.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/tls-1.5.4
hs-libraries:         HStls-1.5.4-G5dyG2FHNNCAlxHHj5pIVt
depends:
    asn1-encoding-0.9.6-5YsNfGFBTVh9BsUPuuc036
    asn1-types-0.3.4-7YdGMufRbFKBkQr82o3Nnr
    async-2.2.2-KsABh1Xq3KKHTwRj3PM458 base-4.14.1.0
    bytestring-0.10.10.0 cereal-0.5.8.1-56yg04wGStN22upOSM9put
    cryptonite-0.27-GQDFsV0e2GLJaPfeS4zGY1
    data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8
    hourglass-0.2.12-AjrhAdG8EuQJjxv7yxpLMw
    memory-0.15.0-359cYXe7lRF64CAN0G53fp mtl-2.2.2
    network-3.1.2.0-6JDKfAnmzxBDIIJL2Fi5PT transformers-0.5.6.2
    x509-1.7.5-HuPIl0SErZEBHvTiyo5deD
    x509-store-1.6.7-GKGM7XwTLT1AZXOrehmhko
    x509-validation-1.6.11-C9hsGmVXvQQLrYsX2ldhmB

haddock-interfaces:   /usr/share/doc/haskell-tls/html/tls.haddock
haddock-html:         /usr/share/doc/haskell-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tls-1.5.4-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tls
version:              1.5.4
visibility:           public
id:                   tls-1.5.4-CWNshN8PdXoGXdjmek8psv
key:                  tls-1.5.4-CWNshN8PdXoGXdjmek8psv
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-tls
synopsis:             TLS/SSL protocol native implementation (Server and Client)
description:
    Native Haskell TLS and SSL protocol implementation for server and client.

    This provides a high-level implementation of a sensitive security protocol,
    eliminating a common set of security issues through the use of the advanced
    type system, high level constructions and common Haskell features.

    Currently implement the SSL3.0, TLS1.0, TLS1.1, TLS1.2 and TLS 1.3 protocol,
    and support RSA and Ephemeral (Elliptic curve and regular) Diffie Hellman key exchanges,
    and many extensions.

    Some debug tools linked with tls, are available through the
    <http://hackage.haskell.org/package/tls-debug/>.

category:             Network
abi:                  6487e66d813e167fed0b8845e50643aa
exposed:              True
exposed-modules:
    Network.TLS Network.TLS.Cipher Network.TLS.Compression
    Network.TLS.Extra Network.TLS.Extra.Cipher Network.TLS.Extra.FFDHE
    Network.TLS.Internal

hidden-modules:
    Network.TLS.Cap Network.TLS.Struct Network.TLS.Struct13
    Network.TLS.Core Network.TLS.Context Network.TLS.Context.Internal
    Network.TLS.Credentials Network.TLS.Backend Network.TLS.Crypto
    Network.TLS.Crypto.DH Network.TLS.Crypto.IES
    Network.TLS.Crypto.Types Network.TLS.ErrT Network.TLS.Extension
    Network.TLS.Handshake Network.TLS.Handshake.Common
    Network.TLS.Handshake.Common13 Network.TLS.Handshake.Certificate
    Network.TLS.Handshake.Key Network.TLS.Handshake.Client
    Network.TLS.Handshake.Server Network.TLS.Handshake.Process
    Network.TLS.Handshake.Random Network.TLS.Handshake.Signature
    Network.TLS.Handshake.State Network.TLS.Handshake.State13
    Network.TLS.Hooks Network.TLS.IO Network.TLS.Imports
    Network.TLS.KeySchedule Network.TLS.MAC Network.TLS.Measurement
    Network.TLS.Packet Network.TLS.Packet13 Network.TLS.Parameters
    Network.TLS.PostHandshake Network.TLS.Record
    Network.TLS.Record.Types Network.TLS.Record.Engage
    Network.TLS.Record.Disengage Network.TLS.Record.State
    Network.TLS.RNG Network.TLS.State Network.TLS.Session
    Network.TLS.Sending Network.TLS.Sending13 Network.TLS.Receiving
    Network.TLS.Receiving13 Network.TLS.Util Network.TLS.Util.ASN1
    Network.TLS.Util.Serialization Network.TLS.Types Network.TLS.Wire
    Network.TLS.X509

import-dirs:          /usr/lib/ghc-8.10.2/site-local/tls-1.5.4
library-dirs:         /usr/lib/ghc-8.10.2/site-local/tls-1.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/tls-1.5.4
hs-libraries:         HStls-1.5.4-CWNshN8PdXoGXdjmek8psv
depends:
    asn1-encoding-0.9.6-Ekj9PH8MbyAKXkftGCJ3DA
    asn1-types-0.3.4-BhmyOFYfRxHKe3mUSnnlsy
    async-2.2.2-9p4LS0aC8xy6EfoRwDUtLj base-4.14.1.0
    bytestring-0.10.10.0 cereal-0.5.8.1-56yg04wGStN22upOSM9put
    cryptonite-0.27-GQDFsV0e2GLJaPfeS4zGY1
    data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8
    hourglass-0.2.12-4Cjx2jMFPnM9b3XS4a0f76
    memory-0.15.0-359cYXe7lRF64CAN0G53fp mtl-2.2.2
    network-3.1.2.0-7C11VX86H1A7hyAq9JvH2M transformers-0.5.6.2
    x509-1.7.5-Jas1wrxHosF5LLmiClBdyd
    x509-store-1.6.7-1p2aIhyZFkE8D9ZHJh053b
    x509-validation-1.6.11-8pMfFJxuZnx6wCAezfdSuj

haddock-interfaces:   /usr/share/doc/haskell-tls/html/tls.haddock
haddock-html:         /usr/share/doc/haskell-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
